@@ -1,9 +1,10 @@
-#include <stdlib.h>
+#include "MaxFlowGraph.h"
 #include <queue>
 #include <R.h>
 #include <Rinternals.h>
 #include "GeneralFunctions.h"
-#include "MaxFlowGraph.h"
+#include <stdlib.h>
+#include <inttypes.h>
 
 void MaxFlowGraph::addEdgeCap(int from, int to, double capacity)
 {
@@ -557,7 +558,7 @@ double MaxFlowGraph::validUntil(bool giveOutput)
                         }
                         if(giveOutput)
                         {
-			  Rprintf("From: %d To: %d Value: %.16f\n", nodeIt-nodes.begin(), edgeIt->to, validLambda);
+			  Rprintf("From: %" PRIu64 " To: %d Value: %.16f\n", nodeIt-nodes.begin(), edgeIt->to, validLambda);
                         }
                     }
                }
